﻿
namespace SilverlightApplicationSchool.Web
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.ComponentModel.DataAnnotations;
    using System.Data.Objects.DataClasses;
    using System.Linq;
    using System.ServiceModel.DomainServices.Hosting;
    using System.ServiceModel.DomainServices.Server;


    // The MetadataTypeAttribute identifies CourseMetadata as the class
    // that carries additional metadata for the Course class.
    [MetadataTypeAttribute(typeof(Course.CourseMetadata))]
    public partial class Course
    {

        // This class allows you to attach custom attributes to properties
        // of the Course class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class CourseMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private CourseMetadata()
            {
            }

            public int CourseID { get; set; }

            public int Credits { get; set; }

            public Department Department { get; set; }

            public int DepartmentID { get; set; }

            public OnlineCourse OnlineCourse { get; set; }

            public OnsiteCourse OnsiteCourse { get; set; }

            public EntityCollection<Person> People { get; set; }

            public EntityCollection<StudentGrade> StudentGrades { get; set; }

            public string Title { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies DepartmentMetadata as the class
    // that carries additional metadata for the Department class.
    [MetadataTypeAttribute(typeof(Department.DepartmentMetadata))]
    public partial class Department
    {

        // This class allows you to attach custom attributes to properties
        // of the Department class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class DepartmentMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private DepartmentMetadata()
            {
            }

            public Nullable<int> Administrator { get; set; }

            public decimal Budget { get; set; }

            public EntityCollection<Course> Courses { get; set; }

            public int DepartmentID { get; set; }

            public string Name { get; set; }

            public DateTime StartDate { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies OfficeAssignmentMetadata as the class
    // that carries additional metadata for the OfficeAssignment class.
    [MetadataTypeAttribute(typeof(OfficeAssignment.OfficeAssignmentMetadata))]
    public partial class OfficeAssignment
    {

        // This class allows you to attach custom attributes to properties
        // of the OfficeAssignment class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class OfficeAssignmentMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private OfficeAssignmentMetadata()
            {
            }

            public int InstructorID { get; set; }

            public string Location { get; set; }

            public Person Person { get; set; }

            public byte[] Timestamp { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies OnlineCourseMetadata as the class
    // that carries additional metadata for the OnlineCourse class.
    [MetadataTypeAttribute(typeof(OnlineCourse.OnlineCourseMetadata))]
    public partial class OnlineCourse
    {

        // This class allows you to attach custom attributes to properties
        // of the OnlineCourse class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class OnlineCourseMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private OnlineCourseMetadata()
            {
            }

            public Course Course { get; set; }

            public int CourseID { get; set; }

            public string URL { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies OnsiteCourseMetadata as the class
    // that carries additional metadata for the OnsiteCourse class.
    [MetadataTypeAttribute(typeof(OnsiteCourse.OnsiteCourseMetadata))]
    public partial class OnsiteCourse
    {

        // This class allows you to attach custom attributes to properties
        // of the OnsiteCourse class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class OnsiteCourseMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private OnsiteCourseMetadata()
            {
            }

            public Course Course { get; set; }

            public int CourseID { get; set; }

            public string Days { get; set; }

            public string Location { get; set; }

            public DateTime Time { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies PersonMetadata as the class
    // that carries additional metadata for the Person class.
    [MetadataTypeAttribute(typeof(Person.PersonMetadata))]
    public partial class Person
    {

        // This class allows you to attach custom attributes to properties
        // of the Person class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class PersonMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private PersonMetadata()
            {
            }

            public EntityCollection<Course> Courses { get; set; }

            public Nullable<DateTime> EnrollmentDate { get; set; }

            public string FirstName { get; set; }

            public Nullable<DateTime> HireDate { get; set; }

            public string LastName { get; set; }

            public OfficeAssignment OfficeAssignment { get; set; }

            public int PersonID { get; set; }

            public EntityCollection<StudentGrade> StudentGrades { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies StudentGradeMetadata as the class
    // that carries additional metadata for the StudentGrade class.
    [MetadataTypeAttribute(typeof(StudentGrade.StudentGradeMetadata))]
    public partial class StudentGrade
    {

        // This class allows you to attach custom attributes to properties
        // of the StudentGrade class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class StudentGradeMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private StudentGradeMetadata()
            {
            }

            public Course Course { get; set; }

            public int CourseID { get; set; }

            public int EnrollmentID { get; set; }

            public Nullable<decimal> Grade { get; set; }

            public Person Person { get; set; }

            public int StudentID { get; set; }
        }
    }
}
